@@ -16,12 +16,18 @@ backtransform <- function(x, transform) {
     draws <- attr(x, "posterior_draws")
 
     if (!is.null(draws)) {
+        dim_pre <- dim(draws)
         draws <- transform(draws)
+        dim_post <- dim(draws)
+        if (!identical(dim_pre, dim_post)) {
+            insight::format_error("The `transform` function must return an object of the same class as its input: a matrix input must return a matrix of the same size, and a vector input must return a vector of the same length.")
+        }
     }
 
     for (col in cols) {
         x[[col]] <- transform(x[[col]])
     }
+
     for (col in c("std.error", "statistic")) {
         x[[col]] <- NULL
     }
