@@ -1,18 +1,11 @@
 get_contrast_data_numeric <- function(model,
                                       newdata,
                                       variable,
-                                      modeldata = NULL,
+                                      modeldata,
                                       ...) {
     
     h <- variable[["eps"]]
 
-    if (is.null(modeldata)) {
-        modeldata <- get_modeldata(model, additional_variables = FALSE)
-    }
-    if (is.null(modeldata)) {
-        modeldata <- newdata
-    }
-
     s <- m <- NA
     if (is.numeric(modeldata[[variable$name]])) {
         s <- stats::sd(modeldata[[variable$name]], na.rm = TRUE)
