@@ -15,7 +15,7 @@ sanitize_variables <- function(variables,
         checkmate::check_character(variables, min.len = 1, names = "unnamed"),
         checkmate::check_list(variables, min.len = 1, names = "unique"),
         combine = "or")
-    
+
     # extensions with no `get_data()`
     if (is.null(modeldata) || nrow(modeldata) == 0) {
         modeldata <- set_variable_class(newdata, model)
@@ -95,7 +95,7 @@ sanitize_variables <- function(variables,
             found <- c(found, v)
         }
     }
-    
+
 
     # matrix predictors
     mc <- attr(newdata, "newdata_matrix_columns")
@@ -113,7 +113,7 @@ sanitize_variables <- function(variables,
             paste(miss, collapse = ", "))
         insight::format_warning(msg)
     }
-    
+
     # sometimes `insight` returns interaction component as if it were a constituent variable
     idx <- !grepl(":", names(predictors))
     predictors <- predictors[idx]
@@ -123,7 +123,7 @@ sanitize_variables <- function(variables,
         msg <- "There is no valid predictor variable. Please change the `variables` argument or supply a new data frame to the `newdata` argument."
         insight::format_error(msg)
     }
-   
+
     # functions to values
     # only for predictions; get_contrast_data_numeric handles this for comparisons()
     # do this before NULL-to-defaults so we can fill it in with default in case of failure
@@ -157,7 +157,7 @@ sanitize_variables <- function(variables,
                         predictors[[v]] <- stats::fivenum(modeldata[[v]])
                     }
                 }
-            
+
             } else {
                 if (calling_function == "comparisons") {
                     predictors[[v]] <- "reference"
@@ -168,15 +168,15 @@ sanitize_variables <- function(variables,
             }
         }
     }
-    
+
     # shortcuts and validity
     for (v in names(predictors)) {
 
         if (isTRUE(checkmate::check_data_frame(predictors[[v]], nrows = nrow(newdata)))) {
             # do nothing, but don't take the other validity check branches
-        
+
         } else if (get_variable_class(modeldata, v, "binary")) {
-            if (!isTRUE(checkmate::check_numeric(predictors[[v]])) || !all(predictors[[v]] %in% 0:1)) {
+            if (!isTRUE(checkmate::check_numeric(predictors[[v]])) || !is_binary(predictors[[v]])) {
                 msg <- sprintf("The `%s` variable is binary. The corresponding entry in the `variables` argument must be 0 or 1.")
                 insight::format_error(msg)
             }
@@ -230,7 +230,7 @@ sanitize_variables <- function(variables,
             if (calling_function == "comparisons") {
                 valid <- c("reference", "sequential", "pairwise", "all", "revpairwise", "revsequential", "revreference")
                 # minmax needs an actual factor in the original data to guarantee correct order of levels.
-                if (is.factor(modeldata[[v]])) { 
+                if (is.factor(modeldata[[v]])) {
                     valid <- c(valid, "minmax")
                 }
                 flag1 <- checkmate::check_choice(predictors[[v]], choices = valid)
@@ -267,7 +267,7 @@ sanitize_variables <- function(variables,
     w <- intersect(w, colnames(newdata))
     others <- w
 
- 
+
     # goals:
     # allow multiple function types: slopes() uses both difference and dydx
     # when comparison is defined, use that if it works or turn back to defaults
@@ -319,7 +319,7 @@ sanitize_variables <- function(variables,
             "value" = predictors[[v]],
             "comparison" = comparison)
     }
-    
+
     # epsilon for finite difference
     for (v in names(predictors)) {
         if (!is.null(eps)) {
@@ -336,7 +336,7 @@ sanitize_variables <- function(variables,
     if (all(names(predictors) %in% dv)) {
         insight::format_error("There are no valid predictor variables. Please make sure your model includes predictors and use the `variables` argument.")
     }
-    
+
     # interaction: get_contrasts() assumes there is only one function when interaction=TRUE
     if (isTRUE(interaction)) {
         for (p in predictors) {
@@ -354,6 +354,6 @@ sanitize_variables <- function(variables,
 
     # output
     out <- list(conditional = predictors, others = others)
-    
+
     return(out)
 }
