@@ -1,6 +1,6 @@
 get_unique_index <- function(x, term_only = FALSE) {
     idx <- c("term", "contrast", grep("^contrast_", colnames(x), value = TRUE))
-    
+
     if (!term_only) {
         by <- attr(x, "by")
         if (isTRUE(checkmate::check_data_frame(by))) {
@@ -13,9 +13,9 @@ get_unique_index <- function(x, term_only = FALSE) {
             idx <- explicit
         }
     }
-    
+
     idx <- intersect(unique(idx), colnames(x))
-    
+
     if (length(idx) == 0) {
         return(NULL)
     } else if (length(idx) == 1) {
@@ -29,7 +29,7 @@ get_unique_index <- function(x, term_only = FALSE) {
             out[[i]] <- NULL
         }
     }
-    
+
     out <- apply(out, 1, paste, collapse = ", ")
     return(out)
 }
@@ -103,7 +103,8 @@ merge_by_rowid <- function(x, y) {
     if ("rowid" %in% colnames(x) && "rowid" %in% colnames(y) && length(mergein) > 0) {
         idx <- c("rowid", mergein)
         if (!data.table::is.data.table(y)) {
-            tmp <- data.table::data.table(y)[, ..idx]
+            data.table::setDT(y)
+            tmp <- y[, ..idx]
         } else {
             tmp <- y[, ..idx]
         }
@@ -117,4 +118,11 @@ merge_by_rowid <- function(x, y) {
         out <- x
     }
     return(out)
-}
\ No newline at end of file
+}
+
+# faster than all(x %in% 0:1)
+is_binary <- function(x) {
+    is.null(x) ||
+    (length(x) == 1 && x %in% 0:1) ||
+    isTRUE(min(x) == 0 && max(x) == 1 && data.table::uniqueN(x) == 2)
+}
