@@ -95,7 +95,7 @@ expect_error(inferences(comparisons(mod, wts = "w"), method = "fwb"), pattern =
 
 # marginal_means not supported
 mod <- lm(Petal.Length ~ Sepal.Length * Sepal.Width * Species, data = iris)
-expect_error(inferences(marginal_means(mod), method = "fwb"), pattern = "not supported")
+expect_error(inferences(marginal_means(mod), method = "fwb"), pattern = "Must inherit")
 
 
 # Issue #856
